@@ -21,13 +21,13 @@ from concurrent import futures
 import enum
 import logging
 import threading
+import urllib
 
 from oslo_utils import encodeutils
-from oslo_utils import excutils
 from oslo_utils import netutils
 from oslo_utils import timeutils
-import six
 from stevedore import driver
+import tenacity
 
 import tooz
 from tooz import _retry
@@ -75,7 +75,7 @@ class Characteristics(enum.Enum):
     SEQUENTIAL = 'SEQUENTIAL'
     """The driver has the following properties:
 
-    * Operations can take effect before or after completion – but all
+    * Operations can take effect before or after completion - but all
       operations retain the constraint that operations from any given process
       must take place in that processes order.
     """
@@ -179,12 +179,15 @@ class Heart(object):
         return not (self._runner is None
                     or not self._runner.is_alive())
 
-    @excutils.forever_retry_uncaught_exceptions
     def _beat_forever_until_stopped(self):
         """Inner beating loop."""
+        retry = tenacity.Retrying(
+            wait=tenacity.wait_fixed(1),
+            before_sleep=tenacity.before_sleep_log(LOG, logging.WARNING),
+        )
         while not self._dead.is_set():
             with timeutils.StopWatch() as w:
-                wait_until_next_beat = self._driver.heartbeat()
+                wait_until_next_beat = retry(self._driver.heartbeat)
             ran_for = w.elapsed()
             has_to_sleep_for = wait_until_next_beat - ran_for
             if has_to_sleep_for < 0:
@@ -545,9 +548,9 @@ class CoordinationDriver(object):
 
     @staticmethod
     def get_members(group_id):
-        """Return the set of all members ids of the specified group.
+        """Return the set of all member ids of a group asynchronously.
 
-        :returns: set of all created group ids
+        :returns: set of all member ids in the specified group
         :rtype: CoordAsyncResult
         """
         raise tooz.NotImplemented
@@ -626,8 +629,7 @@ class CoordinationDriver(object):
         pass
 
 
-@six.add_metaclass(abc.ABCMeta)
-class CoordAsyncResult(object):
+class CoordAsyncResult(object, metaclass=abc.ABCMeta):
     """Representation of an asynchronous task.
 
     Every call API returns an CoordAsyncResult object on which the result or
@@ -636,7 +638,7 @@ class CoordAsyncResult(object):
     """
 
     @abc.abstractmethod
-    def get(self, timeout=10):
+    def get(self, timeout=None):
         """Retrieve the result of the corresponding asynchronous call.
 
         :param timeout: block until the timeout expire.
@@ -783,12 +785,12 @@ def get_coordinator(backend_url, member_id,
                    arguments query string)
     """
     parsed_url = netutils.urlsplit(backend_url)
-    parsed_qs = six.moves.urllib.parse.parse_qs(parsed_url.query)
+    parsed_qs = urllib.parse.parse_qs(parsed_url.query)
     if kwargs:
         options = {}
-        for (k, v) in six.iteritems(kwargs):
+        for (k, v) in kwargs.items():
             options[k] = [v]
-        for (k, v) in six.iteritems(parsed_qs):
+        for (k, v) in parsed_qs.items():
             if k not in options:
                 options[k] = v
     else:
