@@ -14,7 +14,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from distutils import version
 import functools
 import logging
 import re
@@ -23,6 +22,7 @@ import threading
 
 from oslo_utils import encodeutils
 from oslo_utils import strutils
+from packaging import version
 import redis
 from redis import exceptions
 from redis import sentinel
@@ -219,7 +219,7 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
     enum member(s) that can be used to interogate how this driver works.
     """
 
-    MIN_VERSION = version.LooseVersion("2.6.0")
+    MIN_VERSION = version.Version("2.6.0")
     """
     The min redis version that this driver requires to operate with...
     """
@@ -267,6 +267,9 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
         'ssl_ca_certs',
         'sentinel',
         'sentinel_fallback',
+        'sentinel_username',
+        'sentinel_password',
+        'sentinel_ssl',
     ])
     """
     Keys that we allow to proxy from the coordinator configuration into the
@@ -288,6 +291,7 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
         'retry_on_timeout',
         'socket_keepalive',
         'ssl',
+        'sentinel_ssl',
     ])
 
     #: Client arguments that are expected to be int convertible.
@@ -391,14 +395,13 @@ return 1
 
     def _check_fetch_redis_version(self, geq_version, not_existent=True):
         if isinstance(geq_version, str):
-            desired_version = version.LooseVersion(geq_version)
-        elif isinstance(geq_version, version.LooseVersion):
+            desired_version = version.Version(geq_version)
+        elif isinstance(geq_version, version.Version):
             desired_version = geq_version
         else:
             raise TypeError("Version check expects a string/version type")
         try:
-            redis_version = version.LooseVersion(
-                self._server_info['redis_version'])
+            redis_version = version.Version(self._server_info['redis_version'])
         except KeyError:
             return (not_existent, None)
         else:
@@ -474,9 +477,23 @@ return 1
             ]
             sentinel_hosts.insert(0, (kwargs.pop('host'), kwargs.pop('port')))
             sentinel_name = kwargs.pop('sentinel')
+            sentinel_kwargs = {}
+            # NOTE(tkajinam): Copy socket_* options, according to the logic
+            # in redis-py
+            for key in kwargs:
+                if key.startswith('socket_'):
+                    sentinel_kwargs[key] = kwargs[key]
+            if kwargs.pop('sentinel_ssl', False):
+                sentinel_kwargs['ssl'] = True
+                for key in ('ssl_certfile', 'ssl_keyfile', 'ssl_ca_certs'):
+                    if key in kwargs:
+                        sentinel_kwargs[key] = kwargs[key]
+            for key in ('username', 'password'):
+                if 'sentinel_' + key in kwargs:
+                    sentinel_kwargs[key] = kwargs.pop('sentinel_' + key)
             sentinel_server = sentinel.Sentinel(
                 sentinel_hosts,
-                sentinel_kwargs=kwargs,
+                sentinel_kwargs=sentinel_kwargs,
                 **kwargs)
             master_client = sentinel_server.master_for(sentinel_name)
             # The master_client is a redis.Redis using a
